@@ -16,12 +16,12 @@
 import os
 
 import octobot_tentacles_manager.models.artifact as artifact
+import octobot_tentacles_manager.constants as constants
 
 
 class TentaclePackage(artifact.Artifact):
     ARTIFACT_NAME = "tentacle package"
     ARTIFACT_SUFFIX = "package"
-    ARTIFACT_VERSION_SEPARATOR = "@"
 
     def __init__(self, name=None):
         super().__init__(name)
@@ -39,11 +39,9 @@ class TentaclePackage(artifact.Artifact):
         """
         self.artifacts.append(new_artifact)
         if len(self.artifacts) == 1:
-            self.name = f"{self.artifacts[0].name}{TentaclePackage.ARTIFACT_VERSION_SEPARATOR}" \
-                        f"{self.artifacts[0].version}"
+            self.name = self.artifacts[0].get_name_with_version()
         elif len(self.artifacts) > 1:
-            self.name = f"{self.artifacts[0].origin_package}{TentaclePackage.ARTIFACT_VERSION_SEPARATOR}" \
-                        f"{self.version}_{self.ARTIFACT_SUFFIX}"
+            self.name = self.get_package_default_name()
 
     def parse_path_in_name_if_any(self) -> None:
         """
@@ -56,6 +54,13 @@ class TentaclePackage(artifact.Artifact):
             self.output_path = split_path[0]
             self.name = split_path[1]
 
+    def get_package_default_name(self) -> str:
+        """
+        :return: the default package name as 'origin_package@version_package'
+        """
+        return f"{self.artifacts[0].origin_package}{constants.ARTIFACT_VERSION_SEPARATOR}" \
+               f"{self.version}_{self.ARTIFACT_SUFFIX}"
+
     def __str__(self):
         str_rep = f"{self.name} {TentaclePackage.ARTIFACT_NAME} ["
         if self.is_valid():
